phones.ContactDetail (Contact detail) — amici1

# `phones.ContactDetail` (Contact detail)

ContactDetail(id, start_date, end_date, detail_type, partner, value, remark, primary)

Master tables : phones.ContactDetails (Contact details)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Start date (start_date) : See `<django.db.models.fields.DateField: start_date>`.

- End date (end_date) : See `<django.db.models.fields.DateField: end_date>`.

- Contact detail type (detail_type) : See `<lino.core.choicelists.ChoiceListField: detail_type>`.

- Partner (partner) : See `<django.db.models.fields.related.ForeignKey: partner>`.

- Value (value) : See `<lino.core.fields.CharField: value>`.

- Remark (remark) : See `<lino.core.fields.CharField: remark>`.

- Primary (primary) : Whether this item is the primary contact detail for this type and this owner. Setting this field will automatically uncheck any previously primary items and update the owner’s contact detail fields.

- Name (name_column) : See `lino_xl.lib.phones.models.ContactDetail.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.phones.models.ContactDetail.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.phones.models.ContactDetail.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
start_date | Start date |
end_date | End date |
detail_type | Contact detail type |
partner | Partner |
value | Value |
remark | Remark |
primary | Primary | Whether this item is the primary contact detail for this type and this owner. Setting this field will automatically uncheck any previously primary items and update the owner’s contact detail fields.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |